import React from 'react';
import PageTypeMatching from '@/highOrderComponent/PageTypeMatching';
import { deepCopy } from '@/baseComponent/utils';
import { getInfo } from '@/highOrderComponent/Service';

const pageSetting = {
  type: 'listTab', // 页面类型
  tabList: {
    tab1: {
      key: 0,
      name: '待审核',
      listConfig: {
        selectRows: true, // 是否可以行选择,
        paging: true, // 是否可以分页,
        searchArea: true, // 是否拥有 搜索区dom,
        buttonArea: true, // 是否拥有 按钮区,
      },
    },
    tab2: {
      name: '已审核',
      key: 1,
      listConfig: {
        selectRows: true, // 是否可以行选择,
        paging: true, // 是否可以分页,
        searchArea: true, // 是否拥有 搜索区dom,
        buttonArea: true, // 是否拥有 按钮区,
      },
    },
  },
};

const pageButton = {
  tab1: [],
  tab2: [],
};

export default function AuditPage({ appId }) {
  const tab1 = {
    search: {
      getInfo: (params, url) => getInfo(params, url, { method: 'GET' }),
      url: '/common/assigneeTasks',
      field: {
        appId: {
          required: true,
          defaultValue: appId,
        },
      },
      condition: [
        {
          key: 'startTime',
          endKey: 'endTime',
          name: '创建时间',
          type: 'rangePicker',
          format: 'YYYY-MM-DD',
        },
        {
          key: 'department',
          name: '扣分部门',
          type: 'select',
        },
      ],
      nameSpan: { big: 8, small: 9 },
      fileSpan: { big: 4, small: 3 },
    },
    tableRowKey: 'id',
    columns: [
      {
        dataIndex: 'insYear',
        title: '年度',
      },
      {
        dataIndex: 'totalScore',
        title: '扣分分值',
      },
      {
        dataIndex: 'departName',
        title: '扣分部门',
      },
      {
        dataIndex: 'reason',
        title: '扣分原因',
      },
      {
        dataIndex: 'recorderDate',
        title: '时间',
      },
      {
        dataIndex: 'auditStatus',
        title: '状态',
        render: text => {
          switch (text) {
            case 4:
              return '进行中';
            case 5:
              return '完成扣分';
            case 1:
              return '已完成';
            case 2:
              return <span style={{ color: 'red' }}>进行中</span>;
            case 0:
              return <span style={{ color: '#1998f0' }}>进行中</span>;
            default:
              return '';
          }
        },
      },
      {
        dataIndex: 'operation',
        title: '操作',
        renderConfig: {
          type: 'component',
          render: args => {
            return null;
          },
        },
      },
    ],
  };
  const pageSearch = {
    tab1,
    tab2: (deepCopy(tab1).search.url = '/common/assigneeDTasks'),
  };
  return (
    <PageTypeMatching pageSetting={pageSetting} pageButton={pageButton} pageSearch={pageSearch} />
  );
}
